@@ -17,6 +17,8 @@ NSRunLoop is an event loop for Cocoa applications, wrapped by
 L<Cocoa::EventLoop>. By using this module, you can use Cocoa based API in
 your AnyEvent application, or AnyEvent within Cocoa applications.
 
+It does not support blocking waits.
+
 =head1 BUGS
 
 Right now, L<Cocoa::EventLoop> (and this module) are in an early
@@ -38,22 +40,21 @@ use Cocoa::EventLoop;
 
 sub io {
    my ($class, %arg) = @_;
-   Cocoa::EventLoop->io (%arg);
+
+   Cocoa::EventLoop->io (%arg)
 }
 
 sub timer {
    my ($class, %arg) = @_;
-   Cocoa::EventLoop->timer (%arg);
+
+   Cocoa::EventLoop->timer (%arg)
 }
 
-sub loop {
-   Cocoa::EventLoop->run;
-}
+# does not support blocking waits
 
-sub one_event {
-   # this actually is not one event, but it's unable to handle it correctly at Cocoa 
-   Cocoa::EventLoop->run_while (0.1);
-}
+#sub loop {
+#   Cocoa::EventLoop->run;
+#}
 
 1;
 
@@ -64,7 +65,7 @@ Daisuke Murase <typester@cpan.org>, Marc Lehmann <schmorp@schmorp.de>.
 =head1 COPYRIGHTS
 
    Copyright (c) 2009 by KAYAC Inc.
-   Copyright (c) 2010 by Marc Lehmann <schmorp@schmorp.de>
+   Copyright (c) 2010,2011 by Marc Lehmann <schmorp@schmorp.de>
 
 =cut
 
